# Biszx Pylint Odoo
Enable custom checks

Code | Description | short name
--- | --- | ---
C9001 | Default function name must be start with \_default_ | biszx-default-func-name
C9002 | Search function name must be start with \_search_ | biszx-search-func-name
C9003 | Compute function name must be start with \_compute_ | biszx-compute-func-name
C9004 | Onchange function name must be start with \_onchange_ | biszx-onchange-func-name
C9005 | Constrains function name must be start with \_check_ | biszx-constrains-func-name
C9006 | Domain function name must be start with \_domain_ | biszx-domain-func-name
